<?php

add_action('admin_menu', 'wpfree_images_add_settings_menu');
function wpfree_images_add_settings_menu() {
    add_options_page(__('WPFree Images Settings', 'wpfree_images'), __('WPFree Images', 'wpfree_images'), 'manage_options', 'wpfree_images_settings', 'wpfree_images_settings_page');
    add_action('admin_init', 'register_wpfree_images_options');
}


function register_wpfree_images_options(){
    register_setting('wpfree_images_options', 'wpfree_images_options', 'wpfree_images_options_validate');
    add_settings_section('wpfree_images_options_section', '', '', 'wpfree_images_settings');
    add_settings_field('language-id', __('Language', 'wpfree_images'), 'wpfree_images_render_language', 'wpfree_images_settings', 'wpfree_images_options_section');
    add_settings_field('per_page-id', __('Images Per Page', 'wpfree_images'), 'wpfree_images_render_per_page', 'wpfree_images_settings', 'wpfree_images_options_section');
    add_settings_field('image_type-id', __('Image Types', 'wpfree_images'), 'wpfree_images_render_image_type', 'wpfree_images_settings', 'wpfree_images_options_section');
    add_settings_field('orientation-id', __('Orientation', 'wpfree_images'), 'wpfree_images_render_orientation', 'wpfree_images_settings', 'wpfree_images_options_section');
    add_settings_field('attribution-id', __('Attribution', 'wpfree_images'), 'wpfree_images_render_attribution', 'wpfree_images_settings', 'wpfree_images_options_section');
    add_settings_field('button-id', __('Button', 'wpfree_images'), 'wpfree_images_render_button', 'wpfree_images_settings', 'wpfree_images_options_section');
}


function wpfree_images_render_language(){
    $options = get_option('wpfree_images_options');
    $languages = array('id' => 'Bahasa Indonesia', 'cs' => 'Čeština', 'de' => 'Deutsch', 'en' => 'English', 'es' => 'Español', 'fr' => 'Français', 'it' => 'Italiano', 'nl' => 'Nederlands', 'no' => 'Norsk', 'hu' => 'Magyar', 'ru' => 'Русский', 'pl' => 'Polski', 'pt' => 'Português', 'ro' => 'Română', 'fi' => 'Suomi', 'sv' => 'Svenska', 'tr' => 'Türkçe', 'ja' => '日本語', 'ko' => '한국어', 'zh' => '简体中文');
    $set_lang = substr(get_locale(), 0, 2);
    if (!$options['language']) $options['language'] = $languages[$set_lang]?$set_lang:'en';
    echo '<select name="wpfree_images_options[language]">';
    foreach ($languages as $k => $v) { echo '<option value="'.$k.'"'.($options['language']==$k?' selected="selected"':'').'>'.$v.'</option>'; }
    echo '</select>';
}

function wpfree_images_render_per_page(){
    $options = get_option('wpfree_images_options');
    echo '<input name="wpfree_images_options[per_page]" type="number" min="10" max="100" value="'.($options['per_page']?$options['per_page']:30).'">';
}

function wpfree_images_render_image_type(){
    $options = get_option('wpfree_images_options');
    ?>
    <label><input name="wpfree_images_options[image_type]" value="all" type="radio"<?= !$options['image_type'] | $options['image_type']=='all'?' checked="checked"':''; ?>> <?= _e('All', 'wpfree_images'); ?></label>
    <br><label><input name="wpfree_images_options[image_type]" value="photo" type="radio"<?= $options['image_type']=='photo'?' checked="checked"':''; ?>> <?= _e('Photos', 'wpfree_images'); ?></label>
    <br><label><input name="wpfree_images_options[image_type]" value="clipart" type="radio"<?= $options['image_type']=='clipart'?' checked="checked"':''; ?>> <?= _e('Cliparts', 'wpfree_images'); ?></label>
    <?php
}

function wpfree_images_render_orientation(){
    $options = get_option('wpfree_images_options');
    ?>
    <label><input name="wpfree_images_options[orientation]" value="all" type="radio"<?= !$options['orientation'] | $options['orientation']=='all'?' checked="checked"':''; ?>> <?= _e('All', 'wpfree_images'); ?></label>
    <br><label><input name="wpfree_images_options[orientation]" value="horizotal" type="radio"<?= $options['orientation']=='horizotal'?' checked="checked"':''; ?>> <?= _e('Hozizontal', 'wpfree_images'); ?></label>
    <br><label><input name="wpfree_images_options[orientation]" value="vertical" type="radio"<?= $options['orientation']=='vertical'?' checked="checked"':''; ?>> <?= _e('Vertical', 'wpfree_images'); ?></label>
    <?php
}

function wpfree_images_render_attribution(){
    $options = get_option('wpfree_images_options');
    echo '<label><input name="wpfree_images_options[attribution]" value="true" type="checkbox"'.(!$options['attribution'] | $options['attribution']=='true'?' checked="checked"':'').'> '.__('Insert image credits', 'wpfree_images').'</label>';
}

function wpfree_images_render_button(){
    $options = get_option('wpfree_images_options');
    echo '<label><input name="wpfree_images_options[button]" value="true" type="checkbox"'.(!$options['button'] | $options['button']=='true'?' checked="checked"':'').'> '.__('Show WPFree button next to "Add Media"', 'wpfree_images').'</label>';
}


function wpfree_images_settings_page() { ?>
    <div class="wrap">
    <h2><?= _e('WPFree Images', 'wpfree_images'); ?></h2>
    <form method="post" action="options.php">
        <?php
            settings_fields('wpfree_images_options');
            do_settings_sections('wpfree_images_settings');
            submit_button();
        ?>
    </form>
    </div>
<?php }


function wpfree_images_options_validate($input){
    $options = get_option('wpfree_images_options');
    $languages = array('cs' => 'Čeština', 'da' => 'Dansk', 'de' => 'Deutsch', 'en' => 'English', 'es' => 'Español', 'fr' => 'Français', 'id' => 'Indonesia', 'it' => 'Italiano', 'hu' => 'Magyar', 'nl' => 'Nederlands', 'no' => 'Norsk', 'pl' => 'Polski', 'pt' => 'Português', 'ro' => 'Română', 'sk' => 'Slovenčina', 'fi' => 'Suomi', 'sv' => 'Svenska', 'tr' => 'Türkçe', 'vi' => 'Việt', 'th' => 'ไทย', 'bg' => 'Български', 'ru' => 'Русский', 'el' => 'Ελληνική', 'ja' => '日本語', 'ko' => '한국어', 'zh' => '简体中文');
    if ($languages[$input['language']]) $options['language'] = $input['language'];
    $per_page = intval($input['per_page']);
    if ($per_page >= 10 and $per_page <= 100) $options['per_page'] = $per_page;
    if (in_array($input['image_type'], array('all', 'photo', 'clipart'))) $options['image_type'] = $input['image_type'];
    if (in_array($input['orientation'], array('all', 'horizotal', 'vertical'))) $options['orientation'] = $input['orientation'];
    if ($input['attribution']) $options['attribution'] = 'true'; else $options['attribution'] = 'false';
    if ($input['button']) $options['button'] = 'true'; else $options['button'] = 'false';
    return $options;
}
?>
